# 焙书

## Introduction

自动化 爬取/翻译/导出 网页生肉书籍

你是否还在为：

1. 生肉无人烤
2. 译者咕咕
3. 翻译质量感人（虽然用爱发电伟大但是...)
4. 译文充满吐槽私货（个人极其厌恶）

而发愁？

随着 `Gemini AI` 和 `GPT4 Turbo` 的推出，日文小说机器翻译的质量已经可以胜过某些人类了。

于是本库诞生来解救诸位。

本品特性：

1. 自带几个常见日轻爬虫，爬取网站文章
2. 支持 `DeepL`, `Gemini AI`, `ChatGPT` 等烤肉机
3. 支持导出至 `EPUB`, 自动发布至 真白萌，ESJ 等站点（未完工）
4. 自带小型 NoSQL 数据库，方便查看编辑
5. 模块化设计，方便自行定制爬虫，烤肉机，导出器

## NOTICE

本品仍在 Beta 开发阶段，用量用法随时改变，效果随机出错，请自行斟酌。愿意测试者也许可以白嫖 `API Key` ? （数量有限不保证）

## Installation

```bash
pip in
```

